Constant Field Values
Contents
com.devonfw.*
-
com.devonfw.module.logging.common.api.LoggingConstants Modifier and Type Constant Field Value public static final StringCORRELATION_ID"correlationId"
-
com.devonfw.module.logging.common.impl.DiagnosticContextFilter Modifier and Type Constant Field Value public static final StringCORRELATION_ID_HEADER_NAME_DEFAULT"X-Correlation-Id"